rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Column

Synopsis

Documentation

type family Column (context :: Context) a where ... Source #

This type family is used to specify columns in Rel8ables. In Column f a, f is the context of the column (which should be left polymorphic in Rel8able definitions), and a is the type of the column.

Equations

Column Result a = a 
Column context a = context a 

data TColumn (a :: Context) b c Source #

Instances

Instances details
type Eval (TColumn f a :: Type -> Type) Source # 
Instance details

Defined in Rel8.Internal.Column

type Eval (TColumn f a :: Type -> Type) = Column f a