rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Expr.Function

Synopsis

Documentation

class Arguments a Source #

This type class is basically Table Expr, where each column of the Table is an argument to the function, but it also has an additional instance for () for calling functions with no arguments.

Minimal complete definition

arguments

Instances

Instances details
Arguments () Source # 
Instance details

Defined in Rel8.Internal.Expr.Function

Methods

arguments :: () -> [PrimExpr]

Table Expr a => Arguments a Source # 
Instance details

Defined in Rel8.Internal.Expr.Function

Methods

arguments :: a -> [PrimExpr]

function :: (Arguments arguments, Sql DBType a) => QualifiedName -> arguments -> Expr a Source #

function name arguments runs the PostgreSQL function name with the arguments arguments returning an Expr a.

primFunction :: Arguments arguments => QualifiedName -> arguments -> PrimExpr Source #

rawFunction :: Arguments arguments => QualifiedName -> arguments -> Expr a Source #

A less safe version of function that does not wrap the return value in a cast.

binaryOperator :: Sql DBType c => QualifiedName -> Expr a -> Expr b -> Expr c Source #

Construct an expression by applying an infix binary operator to two operands.

rawBinaryOperator :: QualifiedName -> Expr a -> Expr b -> Expr c Source #

A less safe version of binaryOperator that does not wrap the return value in a cast.