rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Expr.Ord

Synopsis

Documentation

(<.) :: Sql DBOrd a => Expr a -> Expr a -> Expr Bool infix 4 Source #

Corresponds to the SQL < operator. Note that this differs from SQL < as null will sort below any other value. For a version of < that exactly matches SQL, see (<?).

(<=.) :: Sql DBOrd a => Expr a -> Expr a -> Expr Bool infix 4 Source #

Corresponds to the SQL <= operator. Note that this differs from SQL <= as null will sort below any other value. For a version of <= that exactly matches SQL, see (<=?).

(>.) :: Sql DBOrd a => Expr a -> Expr a -> Expr Bool infix 4 Source #

Corresponds to the SQL > operator. Note that this differs from SQL > as null will sort below any other value. For a version of > that exactly matches SQL, see (>?).

(>=.) :: Sql DBOrd a => Expr a -> Expr a -> Expr Bool infix 4 Source #

Corresponds to the SQL >= operator. Note that this differs from SQL > as null will sort below any other value. For a version of >= that exactly matches SQL, see (>=?).

(<?) :: DBOrd a => Expr (Maybe a) -> Expr (Maybe a) -> Expr Bool infix 4 Source #

Corresponds to the SQL < operator. Returns null if either arguments are null.

(<=?) :: DBOrd a => Expr (Maybe a) -> Expr (Maybe a) -> Expr Bool infix 4 Source #

Corresponds to the SQL <= operator. Returns null if either arguments are null.

(>?) :: DBOrd a => Expr (Maybe a) -> Expr (Maybe a) -> Expr Bool infix 4 Source #

Corresponds to the SQL > operator. Returns null if either arguments are null.

(>=?) :: DBOrd a => Expr (Maybe a) -> Expr (Maybe a) -> Expr Bool infix 4 Source #

Corresponds to the SQL >= operator. Returns null if either arguments are null.

leastExpr :: Sql DBOrd a => Expr a -> Expr a -> Expr a Source #

Given two expressions, return the expression that sorts less than the other.

Corresponds to the SQL least() function.

greatestExpr :: Sql DBOrd a => Expr a -> Expr a -> Expr a Source #

Given two expressions, return the expression that sorts greater than the other.

Corresponds to the SQL greatest() function.