rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Expr.Order

Synopsis

Documentation

asc :: DBOrd a => Order (Expr a) Source #

Sort a column in ascending order.

desc :: DBOrd a => Order (Expr a) Source #

Sort a column in descending order.

nullsFirst :: Order (Expr a) -> Order (Expr (Maybe a)) Source #

Transform an ordering so that null values appear first. This corresponds to NULLS FIRST in SQL.

nullsLast :: Order (Expr a) -> Order (Expr (Maybe a)) Source #

Transform an ordering so that null values appear last. This corresponds to NULLS LAST in SQL.