rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Expr.Serialize

Synopsis

Documentation

litExpr :: Sql DBType a => a -> Expr a Source #

Produce an expression from a literal.

Note that you can usually use lit, but litExpr can solve problems of inference in polymorphic code.