rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Expr.Window

Synopsis

Documentation

cumulative :: forall (fold :: Fold) i a. Aggregator' fold i a -> Window i a Source #

cumulative allows the use of aggregation functions in Window expressions. In particular, cumulative sum (when combined with orderPartitionBy) gives a running total, also known as a "cumulative sum", hence the name cumulative.

lagExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a) Source #

Applies lag to the column selected by the given function.

leadExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a) Source #

Applies lead to the column selected by the given function.

firstValueExprOn :: (i -> Expr a) -> Window i (Expr a) Source #

Applies firstValue to the column selected by the given function.

lastValueExprOn :: (i -> Expr a) -> Window i (Expr a) Source #

Applies lastValue to the column selected by the given function.