rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Query.Window

Synopsis

Documentation

window :: Window a b -> Query a -> Query b Source #

window runs a query composed of expressions containing window functions. window is similar to aggregate, with the main difference being that in a window query, each input row corresponds to one output row, whereas aggregation queries fold the entire input query down into a single row. To put this into a Haskell context, aggregate is to foldl as window is to scanl.