rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Statement.Delete

Synopsis

Documentation

data Delete a where Source #

The constituent parts of a DELETE statement.

Constructors

Delete 

Fields

  • :: forall names exprs using a. Selects names exprs
     
  • => { from :: TableSchema names

    Which table to delete from.

  •    , using :: Query using

    USING clause — this can be used to join against other tables, and its results can be referenced in the WHERE clause

  •    , deleteWhere :: using -> exprs -> Expr Bool

    Which rows should be selected for deletion.

  •    , returning :: Returning names a

    What to return from the DELETE statement.

  •    } -> Delete a
     

delete :: Delete a -> Statement a Source #

Build a DELETE Statement.