rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Statement.Run

Synopsis

Documentation

run_ :: Statement exprs -> Statement () () Source #

Convert a Statement to a runnable Statement, disregarding the results of that statement (if any).

run_ :: Rel8.Statement exprs -> Hasql.Statement () ()

runN :: Statement () -> Statement () Int64 Source #

Convert a Statement to a runnable Statement, returning the number of rows affected by that statement (for inserts, updates or Rel8.delete's with NoReturning).

runN :: Rel8.Statement () -> Hasql.Statement () Int64

run1 :: Serializable exprs a => Statement (Query exprs) -> Statement () a Source #

Convert a Statement to a runnable Statement, processing the result of the statement as a single row. If the statement returns a number of rows other than 1, a runtime exception is thrown.

run1 :: Serializable exprs a => Rel8.Statement (Query exprs) -> Hasql.Statement () a

runMaybe :: Serializable exprs a => Statement (Query exprs) -> Statement () (Maybe a) Source #

Convert a Statement to a runnable Statement, processing the result of the statement as Maybe a single row. If the statement returns a number of rows other than 0 or 1, a runtime exception is thrown.

runMaybe :: Serializable exprs a => Rel8.Statement (Query exprs) -> Hasql.Statement () (Maybe a)

run :: Serializable exprs a => Statement (Query exprs) -> Statement () [a] Source #

Convert a Statement to a runnable Statement, processing the result of the statement as a list of rows.

run :: Serializable exprs a => Rel8.Statement (Query exprs) -> Hasql.Statement () [a]

runVector :: Serializable exprs a => Statement (Query exprs) -> Statement () (Vector a) Source #

Convert a Statement to a runnable Statement, processing the result of the statement as a Vector of rows.

runVector :: Serializable exprs a => Rel8.Statement (Query exprs) -> Hasql.Statement () (Vector a)