rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Statement.Update

Synopsis

Documentation

data Update a where Source #

The constituent parts of an UPDATE statement.

Constructors

Update 

Fields

  • :: forall names exprs from a. Selects names exprs
     
  • => { target :: TableSchema names

    Which table to update.

  •    , from :: Query from

    FROM clause — this can be used to join against other tables, and its results can be referenced in the SET and WHERE clauses.

  •    , set :: from -> exprs -> exprs

    How to update each selected row.

  •    , updateWhere :: from -> exprs -> Expr Bool

    Which rows to select for update.

  •    , returning :: Returning names a

    What to return from the UPDATE statement.

  •    } -> Update a
     

update :: Update a -> Statement a Source #

Build an UPDATE Statement.