rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Statement.View

Synopsis

Documentation

createView :: Selects names exprs => TableSchema names -> Query exprs -> Statement () () Source #

Given a TableSchema and Query, createView runs a CREATE VIEW statement that will save the given query as a view. This can be useful if you want to share Rel8 queries with other applications.

createOrReplaceView :: Selects names exprs => TableSchema names -> Query exprs -> Statement () () Source #

Given a TableSchema and Query, createOrReplaceView runs a CREATE OR REPLACE VIEW statement that will save the given query as a view, replacing the current view definition if it exists and adheres to the restrictions in place for replacing a view in PostgreSQL.