rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Table.Bool

Synopsis

Documentation

bool :: Table Expr a => a -> a -> Expr Bool -> a Source #

Case analysis for an Expr Bool. Corresponds to bool.

bool x y p returns x if p is False, and returns y if p is True.

case_ :: Table Expr a => [(Expr Bool, a)] -> a -> a Source #

Produce a table expression from a list of alternatives. Returns the first table where the Expr Bool expression is True. If no alternatives are true, the given default is returned.

nullable :: Table Expr b => b -> (Expr a -> b) -> Expr (Maybe a) -> b Source #

Like maybe, but to eliminate null.