rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Table.Order

Synopsis

Documentation

ascTable :: OrdTable a => Order a Source #

Construct an Order for a Table by sorting all columns into ascending orders (any nullable columns will be sorted with NULLS FIRST).

descTable :: OrdTable a => Order a Source #

Construct an Order for a Table by sorting all columns into descending orders (any nullable columns will be sorted with NULLS LAST).