rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Table.Transpose

Synopsis

Documentation

class (Table from a, Table to b, Congruent a b, b ~ Transpose to a, a ~ Transpose from b) => Transposes (from :: Context) (to :: Context) a b | a -> from, b -> to, a to -> b, b from -> a Source #

Transposes from to a b means that a and b are Tables, in the from and to contexts respectively, which share the same underlying structure. In other words, b is a version of a transposed from the from context to the to context (and vice versa).

Instances

Instances details
(Table from a, Table to b, Congruent a b, b ~ Transpose to a, a ~ Transpose from b) => Transposes from to a b Source # 
Instance details

Defined in Rel8.Internal.Table.Transpose