rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Table.Window

Synopsis

Documentation

currentRow :: Window a a Source #

Return every column of the current row of a window query.

lag :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a) Source #

lag n returns the row n rows before the current row in a given window. Returns nothingTable if n is out of bounds.

lagOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a) Source #

Applies lag to the columns selected by the given function.

lead :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a) Source #

lead n returns the row n rows after the current row in a given window. Returns nothingTable if n is out of bounds.

leadOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a) Source #

Applies lead to the columns selected by the given function.

firstValue :: Table Expr a => Window a a Source #

firstValue returns the first row of the window of the current row.

firstValueOn :: Table Expr a => (i -> a) -> Window i a Source #

Applies firstValue to the columns selected by the given function.

lastValue :: Table Expr a => Window a a Source #

lastValue returns the first row of the window of the current row.

lastValueOn :: Table Expr a => (i -> a) -> Window i a Source #

Applies lastValue to the columns selected by the given function.

nthValue :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a) Source #

nthValue n returns the nth row of the window of the current row. Returns nothingTable if n is out of bounds.

nthValueOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a) Source #

Applies nthValue to the columns selected by the given function.