rel8-internal
Safe HaskellNone
LanguageHaskell2010

Rel8.Internal.Type

Synopsis

Documentation

class NotNull a => DBType a where Source #

Haskell types that can be represented as expressions in a database. There should be an instance of DBType for all column types in your database schema (e.g., int, timestamptz, etc).

Rel8 comes with stock instances for most default types in PostgreSQL, so you should only need to derive instances of this class for custom database types, such as types defined in PostgreSQL extensions, or custom domain types.

Instances

Instances details
DBType Object Source #

Corresponds to jsonb

Instance details

Defined in Rel8.Internal.Type

DBType Value Source #

Corresponds to jsonb

Instance details

Defined in Rel8.Internal.Type

DBType ByteString Source #

Corresponds to bytea

Instance details

Defined in Rel8.Internal.Type

DBType ByteString Source #

Corresponds to bytea

Instance details

Defined in Rel8.Internal.Type

DBType Int16 Source #

Corresponds to int2

Instance details

Defined in Rel8.Internal.Type

DBType Int32 Source #

Corresponds to int4

Instance details

Defined in Rel8.Internal.Type

DBType Int64 Source #

Corresponds to int8

Instance details

Defined in Rel8.Internal.Type

DBType IPRange Source #

Corresponds to inet

Instance details

Defined in Rel8.Internal.Type

DBType EitherTag Source # 
Instance details

Defined in Rel8.Internal.Type.Tag

DBType MaybeTag Source # 
Instance details

Defined in Rel8.Internal.Type.Tag

DBType Tag Source # 
Instance details

Defined in Rel8.Internal.Type.Tag

DBType Scientific Source #

Corresponds to numeric

Instance details

Defined in Rel8.Internal.Type

DBType Text Source #

Corresponds to text

Instance details

Defined in Rel8.Internal.Type

DBType Text Source #

Corresponds to text

Instance details

Defined in Rel8.Internal.Type

DBType Day Source #

Corresponds to date

Instance details

Defined in Rel8.Internal.Type

DBType UTCTime Source #

Corresponds to timestamptz

Instance details

Defined in Rel8.Internal.Type

DBType CalendarDiffTime Source #

Corresponds to interval

Instance details

Defined in Rel8.Internal.Type

DBType LocalTime Source #

Corresponds to timestamp

Instance details

Defined in Rel8.Internal.Type

DBType TimeOfDay Source #

Corresponds to time

Instance details

Defined in Rel8.Internal.Type

DBType UUID Source #

Corresponds to uuid

Instance details

Defined in Rel8.Internal.Type

DBType Bool Source #

Corresponds to bool

Instance details

Defined in Rel8.Internal.Type

DBType Char Source #

Corresponds to char

Instance details

Defined in Rel8.Internal.Type

DBType Double Source #

Corresponds to float8 and double precision

Instance details

Defined in Rel8.Internal.Type

DBType Float Source #

Corresponds to float4 and real

Instance details

Defined in Rel8.Internal.Type

DBType (CI Text) Source #

Corresponds to citext

Instance details

Defined in Rel8.Internal.Type

DBType (CI Text) Source #

Corresponds to citext

Instance details

Defined in Rel8.Internal.Type

Sql DBType a => DBType (NonEmpty a) Source # 
Instance details

Defined in Rel8.Internal.Type

DBRange a => DBType (Range a) Source # 
Instance details

Defined in Rel8.Internal.Data.Range

DBRange a => DBType (Multirange a) Source # 
Instance details

Defined in Rel8.Internal.Data.Range

DBComposite a => DBType (Composite a) Source # 
Instance details

Defined in Rel8.Internal.Type.Composite

DBEnum a => DBType (Enum a) Source # 
Instance details

Defined in Rel8.Internal.Type.Enum

(FromJSON a, ToJSON a) => DBType (JSONBEncoded a) Source # 
Instance details

Defined in Rel8.Internal.Type.JSONBEncoded

(FromJSON a, ToJSON a) => DBType (JSONEncoded a) Source # 
Instance details

Defined in Rel8.Internal.Type.JSONEncoded

(Read a, Show a, Typeable a) => DBType (ReadShow a) Source # 
Instance details

Defined in Rel8.Internal.Type.ReadShow

Sql DBType a => DBType [a] Source # 
Instance details

Defined in Rel8.Internal.Type

PowerOf10 n => DBType (Fixed n) Source #

Corresponds to numeric(1000, log₁₀ n)

Instance details

Defined in Rel8.Internal.Type