| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Type.Ord
Documentation
class DBEq a => DBOrd a Source #
The class of database types that support the <, <=, > and >=
operators.
Instances
class DBOrd a => DBMax a Source #
The class of database types that support the max aggregation function.
Instances
class DBOrd a => DBMin a Source #
The class of database types that support the min aggregation function.