| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Aggregate.Function
Synopsis
- aggregateFunction :: (Table Expr i, Sql DBType a) => QualifiedName -> Aggregator1 i (Expr a)
- rawAggregateFunction :: Table Expr i => QualifiedName -> Aggregator1 i (Expr a)
Documentation
aggregateFunction :: (Table Expr i, Sql DBType a) => QualifiedName -> Aggregator1 i (Expr a) Source #
aggregateFunction allows the use use of custom aggregation functions
or PostgreSQL aggregation functions which are not otherwise supported by
Rel8.
rawAggregateFunction :: Table Expr i => QualifiedName -> Aggregator1 i (Expr a) Source #