Rel8.Internal.Column
type family Column (context :: Context) a where ... Source #
This type family is used to specify columns in Rel8ables. In Column f a, f is the context of the column (which should be left polymorphic in Rel8able definitions), and a is the type of the column.
Rel8able
Column f a
f
a
Equations
data TColumn (a :: Context) b c Source #
Defined in Rel8.Internal.Column