| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Expr.Function
Synopsis
- class Arguments a
- function :: (Arguments arguments, Sql DBType a) => QualifiedName -> arguments -> Expr a
- primFunction :: Arguments arguments => QualifiedName -> arguments -> PrimExpr
- rawFunction :: Arguments arguments => QualifiedName -> arguments -> Expr a
- binaryOperator :: Sql DBType c => QualifiedName -> Expr a -> Expr b -> Expr c
- rawBinaryOperator :: QualifiedName -> Expr a -> Expr b -> Expr c
Documentation
This type class is basically , where each column of the
Table ExprTable is an argument to the function, but it also has an additional
instance for () for calling functions with no arguments.
Minimal complete definition
arguments
primFunction :: Arguments arguments => QualifiedName -> arguments -> PrimExpr Source #
rawFunction :: Arguments arguments => QualifiedName -> arguments -> Expr a Source #
A less safe version of function that does not wrap the return value in
a cast.
binaryOperator :: Sql DBType c => QualifiedName -> Expr a -> Expr b -> Expr c Source #
Construct an expression by applying an infix binary operator to two operands.
rawBinaryOperator :: QualifiedName -> Expr a -> Expr b -> Expr c Source #
A less safe version of binaryOperator that does not wrap the return
value in a cast.