| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Expr.Subscript
Documentation
unsafeSubscript :: Sql DBType b => Expr a -> Expr i -> Expr b Source #
will generate the SQL unsafeSubscript a ia[i].
Note that this function is not type checked and the generated SQL has no casts. This is only intended an escape hatch to be used if Rel8 cannot otherwise express the expression you need. If you find yourself using this function, please let us know, as it may indicate that something is missing from Rel8!
unsafeSubscripts :: (Table Expr i, Sql DBType b) => Expr a -> i -> Expr b Source #
will generate the SQL unsafeSubscripts a (i, j)a[i][j].
Note that this function is not type checked and the generated SQL has no casts. This is only intended an escape hatch to be used if Rel8 cannot otherwise express the expression you need. If you find yourself using this function, please let us know, as it may indicate that something is missing from Rel8!