| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Expr.Window
Synopsis
- cumulative :: forall (fold :: Fold) i a. Aggregator' fold i a -> Window i a
- rowNumber :: Window i (Expr Int64)
- rank :: Window i (Expr Int64)
- denseRank :: Window i (Expr Int64)
- percentRank :: Window i (Expr Double)
- cumeDist :: Window i (Expr Double)
- ntile :: Expr Int32 -> Window i (Expr Int32)
- lagExpr :: Expr Int32 -> Expr a -> Window (Expr a) (Expr a)
- lagExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a)
- leadExpr :: Expr Int32 -> Expr a -> Window (Expr a) (Expr a)
- leadExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a)
- firstValueExpr :: Window (Expr a) (Expr a)
- firstValueExprOn :: (i -> Expr a) -> Window i (Expr a)
- lastValueExpr :: Window (Expr a) (Expr a)
- lastValueExprOn :: (i -> Expr a) -> Window i (Expr a)
- nthValueExpr :: Expr Int32 -> Window (Expr a) (Expr (Nullify a))
- nthValueExprOn :: Expr Int32 -> (i -> Expr a) -> Window i (Expr (Nullify a))
Documentation
cumulative :: forall (fold :: Fold) i a. Aggregator' fold i a -> Window i a Source #
cumulative allows the use of aggregation functions in Window
expressions. In particular,
(when combined with cumulative sumorderPartitionBy) gives a running total,
also known as a "cumulative sum", hence the name cumulative.
lagExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a) Source #
Applies lag to the column selected by the given function.
leadExprOn :: Expr Int32 -> Expr a -> (i -> Expr a) -> Window i (Expr a) Source #
Applies lead to the column selected by the given function.
firstValueExprOn :: (i -> Expr a) -> Window i (Expr a) Source #
Applies firstValue to the column selected by the given function.
lastValueExprOn :: (i -> Expr a) -> Window i (Expr a) Source #
Applies lastValue to the column selected by the given function.