| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Query.Aggregate
Synopsis
- aggregate :: (Table Expr i, Table Expr a) => Aggregator i a -> Query i -> Query a
- aggregate1 :: forall i (fold :: Fold) a. Table Expr i => Aggregator' fold i a -> Query i -> Query a
- aggregateU :: forall i (fold :: Fold) a. Unpackspec i i -> Aggregator' fold i a -> Query i -> Query a
- countRows :: Query a -> Query (Expr Int64)
Documentation
aggregate :: (Table Expr i, Table Expr a) => Aggregator i a -> Query i -> Query a Source #
Apply an Aggregator to all rows returned by a Query. If the Query
is empty, then a single "fallback" row is returned, composed of the
identity elements of the constituent aggregation functions.
aggregate1 :: forall i (fold :: Fold) a. Table Expr i => Aggregator' fold i a -> Query i -> Query a Source #
Apply an Aggregator1 to all rows returned by a Query. If
the Query is empty, then zero rows are returned.
aggregateU :: forall i (fold :: Fold) a. Unpackspec i i -> Aggregator' fold i a -> Query i -> Query a Source #