Rel8.Internal.Query.Limit
limit :: Word -> Query a -> Query a Source #
limit n select at most n rows from a query. limit n is equivalent to the SQL LIMIT n.
limit n
n
LIMIT n
offset :: Word -> Query a -> Query a Source #
offset n drops the first n rows from a query. offset n is equivalent to the SQL OFFSET n.
offset n
OFFSET n