Rel8.Internal.Query.Rebind
rebind :: Table Expr a => String -> a -> Query a Source #
rebind takes a variable name, some expressions, and binds each of them to a new variable in the SQL. The a returned consists only of these variables. It's essentially a let binding for Postgres expressions.
rebind
a
let
hrebind :: HTable t => String -> t Expr -> Query (t Expr) Source #