| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Query.Set
Synopsis
- union :: EqTable a => Query a -> Query a -> Query a
- unionAll :: Table Expr a => Query a -> Query a -> Query a
- intersect :: EqTable a => Query a -> Query a -> Query a
- intersectAll :: EqTable a => Query a -> Query a -> Query a
- except :: EqTable a => Query a -> Query a -> Query a
- exceptAll :: EqTable a => Query a -> Query a -> Query a
Documentation
union :: EqTable a => Query a -> Query a -> Query a Source #
Combine the results of two queries of the same type, collapsing
duplicates. union a b is the same as the SQL statement a UNION b.
unionAll :: Table Expr a => Query a -> Query a -> Query a Source #
Combine the results of two queries of the same type, retaining duplicates.
unionAll a b is the same as the SQL statement a UNION ALL b.
intersect :: EqTable a => Query a -> Query a -> Query a Source #
Find the intersection of two queries, collapsing duplicates. intersect a
b is the same as the SQL statement a INTERSECT b.
intersectAll :: EqTable a => Query a -> Query a -> Query a Source #
Find the intersection of two queries, retaining duplicates. intersectAll
a b is the same as the SQL statement a INTERSECT ALL b.