Rel8.Internal.Query.Values
values :: (Table Expr a, Foldable f) => f a -> Query a Source #
Construct a query that returns the given input list of rows. This is like folding a list of return statements under union, but uses the SQL VALUES expression for efficiency.
return
union
VALUES