| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Schema.Table
Synopsis
- data TableSchema names = TableSchema {
- name :: QualifiedName
- columns :: names
- ppTable :: TableSchema a -> Doc
Documentation
data TableSchema names Source #
The schema for a table. This is used to specify the name and schema that a
table belongs to (the FROM part of a SQL query), along with the schema of
the columns within this table.
For each selectable table in your database, you should provide a
TableSchema in order to interact with the table via Rel8.
Constructors
| TableSchema | |
Fields
| |
Instances
| Functor TableSchema Source # | |
Defined in Rel8.Internal.Schema.Table Methods fmap :: (a -> b) -> TableSchema a -> TableSchema b # (<$) :: a -> TableSchema b -> TableSchema a # | |
ppTable :: TableSchema a -> Doc Source #