| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Statement.Prepared
Documentation
prepared :: forall a b i o. Serializable a i => (Statement b -> Statement () o) -> (a -> Statement b) -> Statement i o Source #
Given a run function that converts a Statement to a
Statement, return a run-like function which instead takes a
parameterized Statement and converts it to a preparable
Statement.
The parameters i are sent to the database directly via PostgreSQL's binary
format. For large amounts of data this can be significantly more efficient
than embedding the values in the statement with lit.