| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Table.NonEmpty
Synopsis
- newtype NonEmptyTable (context :: Context) a = NonEmptyTable (HNonEmptyTable (Columns a) (Context a))
- ($+) :: Projecting a (Expr b) => Projection a (Expr b) -> NonEmptyTable Expr a -> Expr (NonEmpty b)
- nonEmptyTable :: Table Expr a => NonEmpty a -> NonEmptyTable Expr a
- nameNonEmptyTable :: Table Name a => a -> NonEmptyTable Name a
- head1 :: Table Expr a => NonEmptyTable Expr a -> a
- index1 :: Table Expr a => Expr Int32 -> NonEmptyTable Expr a -> NullTable Expr a
- last1 :: Table Expr a => NonEmptyTable Expr a -> a
- length1 :: Table Expr a => NonEmptyTable Expr a -> Expr Int32
Documentation
newtype NonEmptyTable (context :: Context) a Source #
A NonEmptyTable value contains one or more instances of a. You
construct NonEmptyTables with some or nonEmptyAgg.
Constructors
| NonEmptyTable (HNonEmptyTable (Columns a) (Context a)) |
Instances
($+) :: Projecting a (Expr b) => Projection a (Expr b) -> NonEmptyTable Expr a -> Expr (NonEmpty b) infixl 4 Source #
Project a single expression out of a NonEmptyTable.
nonEmptyTable :: Table Expr a => NonEmpty a -> NonEmptyTable Expr a Source #
Construct a NonEmptyTable from a non-empty list of expressions.
Arguments
| :: Table Name a | |
| => a | The names of the columns of elements of the list. |
| -> NonEmptyTable Name a |
Construct a NonEmptyTable in the Name context. This can be useful if
you have a NonEmptyTable that you are storing in a table and need to
construct a TableSchema.
head1 :: Table Expr a => NonEmptyTable Expr a -> a Source #
Get the first element of a NonEmptyTable.
last1 :: Table Expr a => NonEmptyTable Expr a -> a Source #
Get the last element of a NonEmptyTable.
length1 :: Table Expr a => NonEmptyTable Expr a -> Expr Int32 Source #
Get the length of a NonEmptyTable