| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Table.Transpose
Documentation
class (Table from a, Table to b, Congruent a b, b ~ Transpose to a, a ~ Transpose from b) => Transposes (from :: Context) (to :: Context) a b | a -> from, b -> to, a to -> b, b from -> a Source #
means that Transposes from to a ba and b are Tables, in the
from and to contexts respectively, which share the same underlying
structure. In other words, b is a version of a transposed from the
from context to the to context (and vice versa).