| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Table.Window
Synopsis
- currentRow :: Window a a
- lag :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a)
- lagOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a)
- lead :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a)
- leadOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a)
- firstValue :: Table Expr a => Window a a
- firstValueOn :: Table Expr a => (i -> a) -> Window i a
- lastValue :: Table Expr a => Window a a
- lastValueOn :: Table Expr a => (i -> a) -> Window i a
- nthValue :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a)
- nthValueOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a)
Documentation
currentRow :: Window a a Source #
Return every column of the current row of a window query.
lag :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a) Source #
returns the row lag nn rows before the current row in a given
window. Returns nothingTable if n is out of bounds.
lagOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a) Source #
Applies lag to the columns selected by the given function.
lead :: Table Expr a => Expr Int32 -> Window a (MaybeTable Expr a) Source #
returns the row lead nn rows after the current row in a given
window. Returns nothingTable if n is out of bounds.
leadOn :: Table Expr a => Expr Int32 -> (i -> a) -> Window i (MaybeTable Expr a) Source #
Applies lead to the columns selected by the given function.
firstValue :: Table Expr a => Window a a Source #
firstValue returns the first row of the window of the current row.
firstValueOn :: Table Expr a => (i -> a) -> Window i a Source #
Applies firstValue to the columns selected by the given function.
lastValue :: Table Expr a => Window a a Source #
lastValue returns the first row of the window of the current row.
lastValueOn :: Table Expr a => (i -> a) -> Window i a Source #
Applies lastValue to the columns selected by the given function.