| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Rel8.Internal.Type
Documentation
class NotNull a => DBType a where Source #
Haskell types that can be represented as expressions in a database. There
should be an instance of DBType for all column types in your database
schema (e.g., int, timestamptz, etc).
Rel8 comes with stock instances for most default types in PostgreSQL, so you should only need to derive instances of this class for custom database types, such as types defined in PostgreSQL extensions, or custom domain types.
Methods